@@ -62,59 +62,120 @@ For ease of understanding, this code works like this:
 Example
 -------
 
-.. code-block:: python
+.. tabs::
 
-    from kivy.lang import Builder
+    .. tab:: Declarative KV style
 
-    from kivymd.app import MDApp
+        .. code-block:: python
+
+            from kivy.lang import Builder
+
+            from kivymd.app import MDApp
 
 
-    class Test(MDApp):
+            class Test(MDApp):
 
-        def build(self):
-            self.theme_cls.material_style = "M3"
-            return Builder.load_string(
-                '''
-    MDScreen:
+                def build(self):
+                    self.theme_cls.material_style = "M3"
+                    self.theme_cls.theme_style = "Dark"
+                    return Builder.load_string(
+                        '''
+            MDScreen:
 
-        MDBottomNavigation:
-            panel_color: "#eeeaea"
-            selected_color_background: "#97ecf8"
-            text_color_active: 0, 0, 0, 1
+                MDBottomNavigation:
+                    #panel_color: "#eeeaea"
+                    selected_color_background: "orange"
+                    text_color_active: "lightgrey"
 
-            MDBottomNavigationItem:
-                name: 'screen 1'
-                text: 'Mail'
-                icon: 'gmail'
-                badge_icon: "numeric-10"
+                    MDBottomNavigationItem:
+                        name: 'screen 1'
+                        text: 'Mail'
+                        icon: 'gmail'
+                        badge_icon: "numeric-10"
 
-                MDLabel:
-                    text: 'Mail'
-                    halign: 'center'
+                        MDLabel:
+                            text: 'Mail'
+                            halign: 'center'
 
-            MDBottomNavigationItem:
-                name: 'screen 2'
-                text: 'Discord'
-                icon: 'discord'
-                badge_icon: "numeric-5"
+                    MDBottomNavigationItem:
+                        name: 'screen 2'
+                        text: 'Twitter'
+                        icon: 'twitter'
+                        badge_icon: "numeric-5"
 
-                MDLabel:
-                    text: 'Discord'
-                    halign: 'center'
+                        MDLabel:
+                            text: 'Twitter'
+                            halign: 'center'
 
-            MDBottomNavigationItem:
-                name: 'screen 3'
-                text: 'LinkedIN'
-                icon: 'linkedin'
+                    MDBottomNavigationItem:
+                        name: 'screen 3'
+                        text: 'LinkedIN'
+                        icon: 'linkedin'
 
-                MDLabel:
-                    text: 'LinkedIN'
-                    halign: 'center'
-    '''
-            )
+                        MDLabel:
+                            text: 'LinkedIN'
+                            halign: 'center'
+            '''
+                    )
 
 
-    Test().run()
+            Test().run()
+
+    .. tab:: Declarative python style
+
+        .. code-block:: python
+
+            from kivymd.app import MDApp
+            from kivymd.uix.bottomnavigation import MDBottomNavigation, MDBottomNavigationItem
+            from kivymd.uix.label import MDLabel
+            from kivymd.uix.screen import MDScreen
+
+
+            class Test(MDApp):
+                def build(self):
+                    self.theme_cls.material_style = "M3"
+                    self.theme_cls.theme_style = "Dark"
+                    return (
+                        MDScreen(
+                            MDBottomNavigation(
+                                MDBottomNavigationItem(
+                                    MDLabel(
+                                        text='Mail',
+                                        halign='center',
+                                    ),
+                                    name='screen 1',
+                                    text='Mail',
+                                    icon='gmail',
+                                    badge_icon="numeric-10",
+                                ),
+                                MDBottomNavigationItem(
+                                    MDLabel(
+                                        text='Twitter',
+                                        halign='center',
+                                    ),
+                                    name='screen 1',
+                                    text='Twitter',
+                                    icon='twitter',
+                                    badge_icon="numeric-10",
+                                ),
+                                MDBottomNavigationItem(
+                                    MDLabel(
+                                        text='LinkedIN',
+                                        halign='center',
+                                    ),
+                                    name='screen 1',
+                                    text='LinkedIN',
+                                    icon='linkedin',
+                                    badge_icon="numeric-10",
+                                ),
+                                selected_color_background="orange",
+                                text_color_active="lightgrey",
+                            )
+                        )
+                    )
+
+
+            Test().run()
 
 .. image:: https://github.com/HeaTTheatR/KivyMD-data/raw/master/gallery/kivymddoc/bottom-navigation.gif
     :align: center
@@ -192,16 +253,13 @@ from kivy.properties import (
 )
 from kivy.uix.behaviors import ButtonBehavior
 from kivy.uix.boxlayout import BoxLayout
-from kivy.uix.screenmanager import ScreenManagerException
+from kivy.uix.screenmanager import FadeTransition, ScreenManagerException
 
 from kivymd import uix_path
 from kivymd.material_resources import STANDARD_INCREMENT
 from kivymd.theming import ThemableBehavior, ThemeManager
 from kivymd.uix.anchorlayout import MDAnchorLayout
-from kivymd.uix.behaviors import (
-    DeclarativeBehavior,
-    FakeRectangularElevationBehavior,
-)
+from kivymd.uix.behaviors import CommonElevationBehavior, DeclarativeBehavior
 from kivymd.uix.behaviors.backgroundcolor_behavior import (
     SpecificBackgroundColorBehavior,
 )
@@ -221,7 +279,7 @@ class MDBottomNavigationHeader(
 ):
     panel_color = ColorProperty([1, 1, 1, 0])
     """
-    Panel color of bottom navigation.
+    Panel color of bottom navigation in (r, g, b, a) or string format.
 
     :attr:`panel_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[1, 1, 1, 0]`.
@@ -249,7 +307,8 @@ class MDBottomNavigationHeader(
 
     text_color_normal = ColorProperty([1, 1, 1, 1])
     """
-    Text color of the label when it is not selected.
+    Text color in (r, g, b, a) or string format of the label when it is not
+    selected.
 
     :attr:`text_color_normal` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[1, 1, 1, 1]`.
@@ -257,7 +316,7 @@ class MDBottomNavigationHeader(
 
     text_color_active = ColorProperty([1, 1, 1, 1])
     """
-    Text color of the label when it is selected.
+    Text color in (r, g, b, a) or string format of the label when it is selected.
 
     :attr:`text_color_active` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[1, 1, 1, 1]`.
@@ -265,7 +324,8 @@ class MDBottomNavigationHeader(
 
     selected_color_background = ColorProperty(None)
     """
-    The background color of the highlighted item when using Material Design v3.
+    The background color in (r, g, b, a) or string format of the highlighted
+    item when using Material Design v3.
 
     .. versionadded:: 1.0.0
 
@@ -413,6 +473,28 @@ class MDBottomNavigationItem(MDTab):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+    def animate_header(
+        self, bottom_navigation_object, bottom_navigation_header_object
+    ) -> None:
+        if bottom_navigation_object.use_text:
+            Animation(_label_font_size=sp(12), d=0.1).start(
+                bottom_navigation_object.previous_tab.header
+            )
+        Animation(
+            _selected_region_width=0,
+            t="in_out_sine",
+            d=0,
+        ).start(bottom_navigation_header_object)
+        Animation(
+            _text_color_normal=bottom_navigation_header_object.text_color_normal
+            if bottom_navigation_object.previous_tab.header.text_color_normal
+            != [1, 1, 1, 1]
+            else self.theme_cls.disabled_hint_text_color,
+            d=0.1,
+        ).start(bottom_navigation_object.previous_tab.header)
+        bottom_navigation_object.previous_tab.header.active = False
+        self.header.active = True
+
     def on_tab_press(self, *args) -> None:
         """Called when clicking on a panel item."""
 
@@ -420,28 +502,13 @@ class MDBottomNavigationItem(MDTab):
         bottom_navigation_header_object = (
             bottom_navigation_object.previous_tab.header
         )
-        bottom_navigation_object.ids.tab_manager.current = self.name
 
         if bottom_navigation_object.previous_tab is not self:
-            if bottom_navigation_object.use_text:
-                Animation(_label_font_size=sp(12), d=0.1).start(
-                    bottom_navigation_object.previous_tab.header
-                )
-            Animation(
-                _selected_region_width=0,
-                t="in_out_sine",
-                d=0,
-            ).start(bottom_navigation_header_object)
-            Animation(
-                _text_color_normal=bottom_navigation_header_object.text_color_normal
-                if bottom_navigation_object.previous_tab.header.text_color_normal
-                != [1, 1, 1, 1]
-                else self.theme_cls.disabled_hint_text_color,
-                d=0.1,
-            ).start(bottom_navigation_object.previous_tab.header)
-            bottom_navigation_object.previous_tab.header.active = False
-            self.header.active = True
-        bottom_navigation_object.previous_tab = self
+            self.animate_header(
+                bottom_navigation_object, bottom_navigation_header_object
+            )
+
+        super().on_tab_press(*args)
 
     def on_disabled(
         self, instance_bottom_navigation_item, disabled_value: bool
@@ -498,6 +565,26 @@ class MDBottomNavigation(DeclarativeBehavior, TabbedPanelBase):
         .. versionadded:: 1.0.0
     """
 
+    transition = ObjectProperty(FadeTransition)
+    """
+    Transition animation of bottom navigation screen manager.
+
+    .. versionadded:: 1.1.0
+
+    :attr:`transition` is an :class:`~kivy.properties.ObjectProperty`
+    and defaults to `FadeTransition`.
+    """
+
+    transition_duration = NumericProperty(0.2)
+    """
+    Duration animation of bottom navigation screen manager.
+
+    .. versionadded:: 1.1.0
+
+    :attr:`transition_duration` is an :class:`~kivy.properties.NumericProperty`
+    and defaults to `0.2`.
+    """
+
     text_color_normal = ColorProperty([1, 1, 1, 1])
     """
     Text color of the label when it is not selected.
@@ -772,8 +859,6 @@ class MDBottomNavigation(DeclarativeBehavior, TabbedPanelBase):
 
 
 class MDBottomNavigationBar(
-    ThemableBehavior,
-    FakeRectangularElevationBehavior,
-    MDFloatLayout,
+    ThemableBehavior, CommonElevationBehavior, MDFloatLayout
 ):
     pass
