@@ -1,14 +1,14 @@
 """
-Components/Relative Layout
-==========================
+Components/RelativeLayout
+=========================
 
-:class:`~kivy.uix.relativelayout.RelativeLayout` class equivalent. Simplifies working
-with some widget properties. For example:
+:class:`~kivy.uix.relativelayout.RelativeLayout` class equivalent.
+Simplifies working with some widget properties. For example:
 
 RelativeLayout
 --------------
 
-.. code-block::
+.. code-block:: kv
 
     RelativeLayout:
         canvas:
@@ -22,7 +22,7 @@ RelativeLayout
 MDRelativeLayout
 ----------------
 
-.. code-block::
+.. code-block:: kv
 
     MDRelativeLayout:
         radius: [25, ]
@@ -32,7 +32,11 @@ MDRelativeLayout
 from kivy.uix.relativelayout import RelativeLayout
 
 from kivymd.uix import MDAdaptiveWidget
+from kivymd.uix.behaviors import DeclarativeBehavior
 
 
-class MDRelativeLayout(RelativeLayout, MDAdaptiveWidget):
-    pass
+class MDRelativeLayout(DeclarativeBehavior, RelativeLayout, MDAdaptiveWidget):
+    """
+    Relative layout class. For more information, see in the
+    :class:`~kivy.uix.relativelayout.RelativeLayout` class documentation.
+    """
