@@ -192,15 +192,10 @@ from kivy.properties import (
 )
 from kivy.uix.behaviors import ToggleButtonBehavior
 from kivy.uix.floatlayout import FloatLayout
-from kivy.utils import get_color_from_hex
 
 from kivymd import uix_path
-from kivymd.color_definitions import colors
 from kivymd.theming import ThemableBehavior
-from kivymd.uix.behaviors import (
-    CircularRippleBehavior,
-    FakeCircularElevationBehavior,
-)
+from kivymd.uix.behaviors import CircularRippleBehavior, CommonElevationBehavior
 from kivymd.uix.floatlayout import MDFloatLayout
 from kivymd.uix.label import MDIcon
 
@@ -258,7 +253,7 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
 
     color_active = ColorProperty(None)
     """
-    Color when the checkbox is in the active state.
+    Color in (r, g, b, a) or string format when the checkbox is in the active state.
 
     .. versionadded:: 1.0.0
 
@@ -276,7 +271,7 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
 
     color_inactive = ColorProperty(None)
     """
-    Color when the checkbox is in the inactive state.
+    Color in (r, g, b, a) or string format when the checkbox is in the inactive state.
 
     .. versionadded:: 1.0.0
 
@@ -294,7 +289,7 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
 
     disabled_color = ColorProperty(None)
     """
-    Color when the checkbox is in the disabled state.
+    Color in (r, g, b, a) or string format when the checkbox is in the disabled state.
 
     .. code-block:: kv
 
@@ -314,7 +309,7 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
 
     selected_color = ColorProperty(None, deprecated=True)
     """
-    Color when the checkbox is in the active state.
+    Color in (r, g, b, a) or string format when the checkbox is in the active state.
 
     .. deprecated:: 1.0.0
         Use :attr:`color_active` instead.
@@ -325,7 +320,7 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
 
     unselected_color = ColorProperty(None, deprecated=True)
     """
-    Color when the checkbox is in the inactive state.
+    Color in (r, g, b, a) or string format when the checkbox is in the inactive state.
 
     .. deprecated:: 1.0.0
         Use :attr:`color_inactive` instead.
@@ -361,8 +356,10 @@ class MDCheckbox(CircularRippleBehavior, ToggleButtonBehavior, MDIcon):
             disabled=self.update_color,
             state=self.update_color,
         )
-        self.theme_cls.bind(primary_color=self.update_primary_color)
-        self.theme_cls.bind(theme_style=self.update_primary_color)
+        self.theme_cls.bind(
+            theme_style=self.update_primary_color,
+            primary_color=self.update_primary_color,
+        )
         self.update_icon()
         self.update_color()
 
@@ -423,7 +420,7 @@ class ThumbIcon(MDIcon):
 
 
 class Thumb(
-    FakeCircularElevationBehavior,
+    CommonElevationBehavior,
     CircularRippleBehavior,
     MDFloatLayout,
 ):
@@ -493,7 +490,8 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     icon_active_color = ColorProperty(None)
     """
-    Thumb icon color when the switch is in the active state (only M3 style).
+    Thumb icon color in (r, g, b, a) or string format when the switch is in the
+    active state (only M3 style).
 
     .. versionadded:: 1.0.0
 
@@ -513,7 +511,8 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     icon_inactive_color = ColorProperty(None)
     """
-    Thumb icon color when the switch is in an inactive state (only M3 style).
+    Thumb icon color in (r, g, b, a) or string format when the switch is in an
+    inactive state (only M3 style).
 
     .. versionadded:: 1.0.0
 
@@ -532,7 +531,7 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     thumb_color_active = ColorProperty(None)
     """
-    The color of the thumb when the switch is active.
+    The color in (r, g, b, a) or string format of the thumb when the switch is active.
 
     .. versionadded:: 1.0.0
 
@@ -551,7 +550,7 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     thumb_color_inactive = ColorProperty(None)
     """
-    The color of the thumb when the switch is inactive.
+    The color in (r, g, b, a) or string format of the thumb when the switch is inactive.
 
     .. versionadded:: 1.0.0
 
@@ -569,7 +568,8 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     thumb_color_disabled = ColorProperty(None)
     """
-    The color of the thumb when the switch is in the disabled state.
+    The color in (r, g, b, a) or string format of the thumb when the switch is
+    in the disabled state.
 
     .. code-block:: kv
 
@@ -587,7 +587,7 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     track_color_active = ColorProperty(None)
     """
-    The color of the track when the switch is active.
+    The color in (r, g, b, a) or string format of the track when the switch is active.
 
     .. code-block:: kv
 
@@ -604,7 +604,7 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     track_color_inactive = ColorProperty(None)
     """
-    The color of the track when the switch is inactive.
+    The color in (r, g, b, a) or string format of the track when the switch is inactive.
 
     .. versionadded:: 1.0.0
 
@@ -622,7 +622,8 @@ class MDSwitch(ThemableBehavior, FloatLayout):
 
     track_color_disabled = ColorProperty(None)
     """
-    The color of the track when the switch is in the disabled state.
+    The color in (r, g, b, a) or string format of the track when the switch is
+    in the disabled state.
 
     .. code-block:: kv
 
