@@ -944,7 +944,6 @@ from kivy.properties import (
 from kivy.uix.anchorlayout import AnchorLayout
 from kivy.uix.behaviors import ToggleButtonBehavior
 from kivy.uix.scrollview import ScrollView
-from kivy.uix.widget import Widget
 from kivy.utils import boundary
 
 from kivymd import uix_path
@@ -953,11 +952,11 @@ from kivymd.icon_definitions import md_icons
 from kivymd.theming import ThemableBehavior, ThemeManager
 from kivymd.uix.behaviors import (
     DeclarativeBehavior,
-    FakeRectangularElevationBehavior,
     RectangularRippleBehavior,
     SpecificBackgroundColorBehavior,
 )
 from kivymd.uix.boxlayout import MDBoxLayout
+from kivymd.uix.card import MDCard
 from kivymd.uix.carousel import MDCarousel
 from kivymd.uix.label import MDLabel
 
@@ -1024,7 +1023,7 @@ class MDTabsLabel(ToggleButtonBehavior, RectangularRippleBehavior, MDLabel):
         Clock.schedule_once(self.tab_bar._label_request_indicator_update, 0)
 
 
-class MDTabsBase(Widget):
+class MDTabsBase:
     """
     This class allow you to create a tab.
     You must create a new class that inherits from MDTabsBase.
@@ -1130,9 +1129,9 @@ class MDTabsBase(Widget):
     This property will affect the Tab's Title Label widget.
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.tab_label = MDTabsLabel(tab=self)
-        super().__init__(**kwargs)
+        super().__init__(*args, **kwargs)
         self.bind(
             icon=self._update_text,
             title=self._update_text,
@@ -1273,9 +1272,7 @@ class MDTabsScrollView(ScrollView):
             _update(self.effect_y, scroll_y)
 
 
-class MDTabsBar(
-    ThemableBehavior, FakeRectangularElevationBehavior, MDBoxLayout
-):
+class MDTabsBar(MDCard):
     """
     This class is just a boxlayout that contains the scroll view for tabs.
     It is also responsible for resizing the tab shortcut when necessary.
@@ -1521,7 +1518,7 @@ class MDTabs(
 
     background_color = ColorProperty(None)
     """
-    Background color of tabs in ``rgba`` format.
+    Background color of tabs in (r, g, b, a) or string format.
 
     :attr:`background_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
@@ -1529,7 +1526,7 @@ class MDTabs(
 
     underline_color = ColorProperty([0, 0, 0, 0])
     """
-    Underline color of tabs in ``rgba`` format.
+    Underline color of tabs in (r, g, b, a) or string format.
 
     :attr:`underline_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `[0, 0, 0, 0]`.
@@ -1537,7 +1534,7 @@ class MDTabs(
 
     text_color_normal = ColorProperty(None)
     """
-    Text color of the label when it is not selected.
+    Text color in (r, g, b, a) or string format of the label when it is not selected.
 
     :attr:`text_color_normal` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
@@ -1545,19 +1542,49 @@ class MDTabs(
 
     text_color_active = ColorProperty(None)
     """
-    Text color of the label when it is selected.
+    Text color in (r, g, b, a) or string format of the label when it is selected.
 
     :attr:`text_color_active` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
     """
 
+    shadow_softness = NumericProperty(12)
+    """
+    See :attr:`kivymd.uix.behaviors.CommonElevationBehavior.shadow_softness`
+    attribute.
+
+    .. versionadded:: 1.1.0
+
+    :attr:`shadow_softness` is an :class:`~kivy.properties.NumericProperty`
+    and defaults to `12`.
+    """
+
+    shadow_color = ColorProperty([0, 0, 0, 0.6])
+    """
+    See :attr:`kivymd.uix.behaviors.CommonElevationBehavior.shadow_color`
+    attribute.
+
+    .. versionadded:: 1.1.0
+
+    :attr:`shadow_color` is an :class:`~kivy.properties.ColorProperty`
+    and defaults to `[0, 0, 0, 0.6]`.
+    """
+
+    shadow_offset = ListProperty((0, 0))
+    """
+    See :attr:`kivymd.uix.behaviors.CommonElevationBehavior.shadow_offset`
+    attribute.
+
+    .. versionadded:: 1.1.0
+
+    :attr:`shadow_offset` is an :class:`~kivy.properties.ListProperty`
+    and defaults to `[0, 0]`.
+    """
+
     elevation = NumericProperty(0)
     """
-    Tab value elevation.
-
-    .. seealso::
-
-        `Behaviors/Elevation <https://kivymd.readthedocs.io/en/latest/behaviors/elevation/index.html>`_
+    See :attr:`kivymd.uix.behaviors.CommonElevationBehavior.elevation`
+    attribute.
 
     :attr:`elevation` is an :class:`~kivy.properties.NumericProperty`
     and defaults to `0`.
@@ -1565,7 +1592,7 @@ class MDTabs(
 
     indicator_color = ColorProperty(None)
     """
-    Color indicator in ``rgba`` format.
+    Color indicator in (r, g, b, a) or string format.
 
     :attr:`indicator_color` is an :class:`~kivy.properties.ColorProperty`
     and defaults to `None`.
